| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
OryKratos.Types
Synopsis
- data LoginFlow = LoginFlow {
- active :: Maybe Text
- created_at :: Maybe UTCTime
- expires_at :: UTCTime
- forced :: Maybe Bool
- id :: Text
- issued_at :: UTCTime
- request_url :: Text
- _type :: Text
- ui :: UiContainer
- updated_at :: Maybe UTCTime
- data LoginViaApiResponse = LoginViaApiResponse {
- session :: Session
- session_token :: Text
- data AuthenticateOKBody = AuthenticateOKBody {
- identity_token :: Text
- status :: Text
- data SubmitSelfServiceLoginFlowWithPasswordMethod = SubmitSelfServiceLoginFlowWithPasswordMethod {}
- data Message = Message {}
- data ErrorContainer = ErrorContainer {}
- data FormField = FormField {}
- data GenericError = GenericError {}
- data HealthNotReadyStatus = HealthNotReadyStatus {}
- data HealthStatus = HealthStatus {}
- data CreateIdentity = CreateIdentity {}
- data CreateRecoveryLink = AdminCreateSelfServiceRecoveryLinkBody {
- expires_in :: Maybe Text
- identity_id :: UUID
- data Identity = Identity {}
- data RevokeSession = RevokeSession {}
- data Session = Session {}
- data UpdateIdentity = UpdateIdentity {}
- data VerifiableIdentityAddress = VerifiableIdentityAddress {}
- data Version = Version {}
- data RecoveryAddress = RecoveryAddress {}
- data ContainerChangeResponseItem = ContainerChangeResponseItem {}
- data ContainerCreateCreatedBody = ContainerCreateCreatedBody {}
- data ContainerTopOKBody = ContainerTopOKBody {}
- data ContainerUpdateOKBody = ContainerUpdateOKBody {}
- data ContainerWaitOKBody = ContainerWaitOKBody {}
- data ContainerWaitOKBodyError = ContainerWaitOKBodyError {}
- data ErrorResponse = ErrorResponse {}
- data GraphDriverData = GraphDriverData {}
- data IdResponse = IdResponse {}
- data ImageSummary = ImageSummary {}
- data ImageDeleteResponseItem = ImageDeleteResponseItem {}
- data JsonError = JsonError {}
- data SelfServiceErrorContainer = SelfServiceErrorContainer {
- created_at :: Maybe UTCTime
- errors :: Value
- id :: Text
- updated_at :: Maybe UTCTime
- data RecoveryFlow = RecoveryFlow {}
- data RecoveryLink = RecoveryLink {}
- data SubmitSelfServiceRecoveryFlowWithLinkMethod = SubmitSelfServiceRecoveryFlowWithLinkMethod {}
- data RegistrationFlow = RegistrationFlow {}
- data RegistrationViaApiResponse = RegistrationViaApiResponse {}
- data SubmitSelfServiceRegistrationFlowWithPasswordMethod = SubmitSelfServiceRegistrationFlowWithPasswordMethod {}
- data SettingsFlow = SettingsFlow {}
- data SettingsViaApiResponse = SettingsViaApiResponse {
- flow :: SettingsFlow
- identity :: Identity
- data SubmitSelfServiceBrowserSettingsOIDCFlowPayload = SubmitSelfServiceBrowserSettingsOIDCFlowPayload {}
- data SubmitSelfServiceSettingsFlowWithPasswordMethod = SubmitSelfServiceSettingsFlowWithPasswordMethod {}
- data VerificationFlow = VerificationFlow {}
- data UiContainer = UiContainer {}
- data UiNode = UiNode {}
- data UiNodeAnchorAttributes = UiNodeAnchorAttributes {}
- data UiNodeImageAttributes = UiNodeImageAttributes {}
- data UiNodeInputAttributes = UiNodeInputAttributes {}
- data UiNodeTextAttributes = UiNodeTextAttributes {}
- data UiText = UiText {}
- data Meta = Meta {}
Documentation
This object represents a login flow. A login flow is initiated at the "Initiate Login API / Browser Flow" endpoint by a client. Once a login flow is completed successfully, a session cookie or session token will be issued.
Constructors
| LoginFlow | |
Fields
| |
Instances
data LoginViaApiResponse Source #
The Response for Login Flows via API
Constructors
| LoginViaApiResponse | |
Fields
| |
Instances
data AuthenticateOKBody Source #
AuthenticateOKBody authenticate o k body
Constructors
| AuthenticateOKBody | |
Fields
| |
Instances
data SubmitSelfServiceLoginFlowWithPasswordMethod Source #
Constructors
| SubmitSelfServiceLoginFlowWithPasswordMethod | |
Fields
| |
Instances
Constructors
| Message | |
Instances
| Eq Message Source # | |
| Data Message Source # | |
Defined in OryKratos.Types.Misc Methods gfoldl :: (forall d b. Data d => c (d -> b) -> d -> c b) -> (forall g. g -> c g) -> Message -> c Message # gunfold :: (forall b r. Data b => c (b -> r) -> c r) -> (forall r. r -> c r) -> Constr -> c Message # toConstr :: Message -> Constr # dataTypeOf :: Message -> DataType # dataCast1 :: Typeable t => (forall d. Data d => c (t d)) -> Maybe (c Message) # dataCast2 :: Typeable t => (forall d e. (Data d, Data e) => c (t d e)) -> Maybe (c Message) # gmapT :: (forall b. Data b => b -> b) -> Message -> Message # gmapQl :: (r -> r' -> r) -> r -> (forall d. Data d => d -> r') -> Message -> r # gmapQr :: forall r r'. (r' -> r -> r) -> r -> (forall d. Data d => d -> r') -> Message -> r # gmapQ :: (forall d. Data d => d -> u) -> Message -> [u] # gmapQi :: Int -> (forall d. Data d => d -> u) -> Message -> u # gmapM :: Monad m => (forall d. Data d => d -> m d) -> Message -> m Message # gmapMp :: MonadPlus m => (forall d. Data d => d -> m d) -> Message -> m Message # gmapMo :: MonadPlus m => (forall d. Data d => d -> m d) -> Message -> m Message # | |
| Show Message Source # | |
| Generic Message Source # | |
| ToJSON Message Source # | |
Defined in OryKratos.Types.Misc | |
| FromJSON Message Source # | |
| type Rep Message Source # | |
Defined in OryKratos.Types.Misc type Rep Message = D1 ('MetaData "Message" "OryKratos.Types.Misc" "ory-kratos-0.0.6.0-9BTeyIjpbIJHN75AXkcTl3" 'False) (C1 ('MetaCons "Message" 'PrefixI 'True) ((S1 ('MetaSel ('Just "context") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Maybe Value)) :*: S1 ('MetaSel ('Just "id") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Maybe Integer))) :*: (S1 ('MetaSel ('Just "text") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Maybe Text)) :*: S1 ('MetaSel ('Just "_type") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Maybe Text))))) | |
data ErrorContainer Source #
Constructors
| ErrorContainer | |
Instances
Field represents a HTML Form Field
Constructors
| FormField | |
Fields
| |
Instances
data GenericError Source #
Error responses are sent when an error (e.g. unauthorized, bad request, ...) occurred.
Constructors
| GenericError | |
Fields
| |
Instances
data HealthNotReadyStatus Source #
Constructors
| HealthNotReadyStatus | |
Instances
data HealthStatus Source #
Constructors
| HealthStatus | |
Instances
data CreateIdentity Source #
Constructors
| CreateIdentity | |
Fields
| |
Instances
data CreateRecoveryLink Source #
Constructors
| AdminCreateSelfServiceRecoveryLinkBody | |
Fields
| |
Instances
Constructors
| Identity | |
Fields
| |
Instances
data RevokeSession Source #
Constructors
| RevokeSession | |
Fields
| |
Instances
Constructors
| Session | |
Instances
| Eq Session Source # | |
| Data Session Source # | |
Defined in OryKratos.Types.Misc Methods gfoldl :: (forall d b. Data d => c (d -> b) -> d -> c b) -> (forall g. g -> c g) -> Session -> c Session # gunfold :: (forall b r. Data b => c (b -> r) -> c r) -> (forall r. r -> c r) -> Constr -> c Session # toConstr :: Session -> Constr # dataTypeOf :: Session -> DataType # dataCast1 :: Typeable t => (forall d. Data d => c (t d)) -> Maybe (c Session) # dataCast2 :: Typeable t => (forall d e. (Data d, Data e) => c (t d e)) -> Maybe (c Session) # gmapT :: (forall b. Data b => b -> b) -> Session -> Session # gmapQl :: (r -> r' -> r) -> r -> (forall d. Data d => d -> r') -> Session -> r # gmapQr :: forall r r'. (r' -> r -> r) -> r -> (forall d. Data d => d -> r') -> Session -> r # gmapQ :: (forall d. Data d => d -> u) -> Session -> [u] # gmapQi :: Int -> (forall d. Data d => d -> u) -> Session -> u # gmapM :: Monad m => (forall d. Data d => d -> m d) -> Session -> m Session # gmapMp :: MonadPlus m => (forall d. Data d => d -> m d) -> Session -> m Session # gmapMo :: MonadPlus m => (forall d. Data d => d -> m d) -> Session -> m Session # | |
| Show Session Source # | |
| Generic Session Source # | |
| ToJSON Session Source # | |
Defined in OryKratos.Types.Misc | |
| FromJSON Session Source # | |
| type Rep Session Source # | |
Defined in OryKratos.Types.Misc type Rep Session = D1 ('MetaData "Session" "OryKratos.Types.Misc" "ory-kratos-0.0.6.0-9BTeyIjpbIJHN75AXkcTl3" 'False) (C1 ('MetaCons "Session" 'PrefixI 'True) ((S1 ('MetaSel ('Just "active") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Maybe Bool)) :*: (S1 ('MetaSel ('Just "authenticated_at") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 UTCTime) :*: S1 ('MetaSel ('Just "expires_at") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 UTCTime))) :*: (S1 ('MetaSel ('Just "id") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 UUID) :*: (S1 ('MetaSel ('Just "identity") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Identity) :*: S1 ('MetaSel ('Just "issued_at") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 UTCTime))))) | |
data UpdateIdentity Source #
Constructors
| UpdateIdentity | |
Fields
| |
Instances
data VerifiableIdentityAddress Source #
Constructors
| VerifiableIdentityAddress | |
Fields
| |
Instances
Instances
| Eq Version Source # | |
| Data Version Source # | |
Defined in OryKratos.Types.Misc Methods gfoldl :: (forall d b. Data d => c (d -> b) -> d -> c b) -> (forall g. g -> c g) -> Version -> c Version # gunfold :: (forall b r. Data b => c (b -> r) -> c r) -> (forall r. r -> c r) -> Constr -> c Version # toConstr :: Version -> Constr # dataTypeOf :: Version -> DataType # dataCast1 :: Typeable t => (forall d. Data d => c (t d)) -> Maybe (c Version) # dataCast2 :: Typeable t => (forall d e. (Data d, Data e) => c (t d e)) -> Maybe (c Version) # gmapT :: (forall b. Data b => b -> b) -> Version -> Version # gmapQl :: (r -> r' -> r) -> r -> (forall d. Data d => d -> r') -> Version -> r # gmapQr :: forall r r'. (r' -> r -> r) -> r -> (forall d. Data d => d -> r') -> Version -> r # gmapQ :: (forall d. Data d => d -> u) -> Version -> [u] # gmapQi :: Int -> (forall d. Data d => d -> u) -> Version -> u # gmapM :: Monad m => (forall d. Data d => d -> m d) -> Version -> m Version # gmapMp :: MonadPlus m => (forall d. Data d => d -> m d) -> Version -> m Version # gmapMo :: MonadPlus m => (forall d. Data d => d -> m d) -> Version -> m Version # | |
| Show Version Source # | |
| Generic Version Source # | |
| ToJSON Version Source # | |
Defined in OryKratos.Types.Misc | |
| FromJSON Version Source # | |
| type Rep Version Source # | |
Defined in OryKratos.Types.Misc | |
data RecoveryAddress Source #
Instances
data ContainerChangeResponseItem Source #
ContainerChangeResponseItem change item in response to ContainerChanges operation
Constructors
| ContainerChangeResponseItem | |
Instances
data ContainerCreateCreatedBody Source #
ContainerCreateCreatedBody OK response to ContainerCreate operation
Constructors
| ContainerCreateCreatedBody | |
Instances
data ContainerTopOKBody Source #
ContainerTopOKBody OK response to ContainerTop operation
Constructors
| ContainerTopOKBody | |
Instances
data ContainerUpdateOKBody Source #
ContainerUpdateOKBody OK response to ContainerUpdate operation
Constructors
| ContainerUpdateOKBody | |
Instances
data ContainerWaitOKBody Source #
ContainerWaitOKBody OK response to ContainerWait operation
Constructors
| ContainerWaitOKBody | |
Fields
| |
Instances
data ContainerWaitOKBodyError Source #
ContainerWaitOKBodyError container waiting error, if any
Constructors
| ContainerWaitOKBodyError | |
Fields
| |
Instances
data ErrorResponse Source #
Constructors
| ErrorResponse | |
Instances
data GraphDriverData Source #
Instances
data IdResponse Source #
IDResponse Response to an API call that returns just an Id
Constructors
| IdResponse | |
Instances
| Eq IdResponse Source # | |
Defined in OryKratos.Types.Misc | |
| Data IdResponse Source # | |
Defined in OryKratos.Types.Misc Methods gfoldl :: (forall d b. Data d => c (d -> b) -> d -> c b) -> (forall g. g -> c g) -> IdResponse -> c IdResponse # gunfold :: (forall b r. Data b => c (b -> r) -> c r) -> (forall r. r -> c r) -> Constr -> c IdResponse # toConstr :: IdResponse -> Constr # dataTypeOf :: IdResponse -> DataType # dataCast1 :: Typeable t => (forall d. Data d => c (t d)) -> Maybe (c IdResponse) # dataCast2 :: Typeable t => (forall d e. (Data d, Data e) => c (t d e)) -> Maybe (c IdResponse) # gmapT :: (forall b. Data b => b -> b) -> IdResponse -> IdResponse # gmapQl :: (r -> r' -> r) -> r -> (forall d. Data d => d -> r') -> IdResponse -> r # gmapQr :: forall r r'. (r' -> r -> r) -> r -> (forall d. Data d => d -> r') -> IdResponse -> r # gmapQ :: (forall d. Data d => d -> u) -> IdResponse -> [u] # gmapQi :: Int -> (forall d. Data d => d -> u) -> IdResponse -> u # gmapM :: Monad m => (forall d. Data d => d -> m d) -> IdResponse -> m IdResponse # gmapMp :: MonadPlus m => (forall d. Data d => d -> m d) -> IdResponse -> m IdResponse # gmapMo :: MonadPlus m => (forall d. Data d => d -> m d) -> IdResponse -> m IdResponse # | |
| Show IdResponse Source # | |
Defined in OryKratos.Types.Misc Methods showsPrec :: Int -> IdResponse -> ShowS # show :: IdResponse -> String # showList :: [IdResponse] -> ShowS # | |
| Generic IdResponse Source # | |
Defined in OryKratos.Types.Misc Associated Types type Rep IdResponse :: Type -> Type # | |
| ToJSON IdResponse Source # | |
Defined in OryKratos.Types.Misc Methods toJSON :: IdResponse -> Value # toEncoding :: IdResponse -> Encoding # toJSONList :: [IdResponse] -> Value # toEncodingList :: [IdResponse] -> Encoding # | |
| FromJSON IdResponse Source # | |
Defined in OryKratos.Types.Misc | |
| type Rep IdResponse Source # | |
Defined in OryKratos.Types.Misc type Rep IdResponse = D1 ('MetaData "IdResponse" "OryKratos.Types.Misc" "ory-kratos-0.0.6.0-9BTeyIjpbIJHN75AXkcTl3" 'False) (C1 ('MetaCons "IdResponse" 'PrefixI 'True) (S1 ('MetaSel ('Just "id") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Text))) | |
data ImageSummary Source #
ImageSummary image summary
Constructors
| ImageSummary | |
Instances
data ImageDeleteResponseItem Source #
ImageDeleteResponseItem image delete response item
Constructors
| ImageDeleteResponseItem | |
Instances
The standard Ory JSON API error format.
Constructors
| JsonError | |
Fields | |
Instances
| Eq JsonError Source # | |
| Data JsonError Source # | |
Defined in OryKratos.Types.Misc Methods gfoldl :: (forall d b. Data d => c (d -> b) -> d -> c b) -> (forall g. g -> c g) -> JsonError -> c JsonError # gunfold :: (forall b r. Data b => c (b -> r) -> c r) -> (forall r. r -> c r) -> Constr -> c JsonError # toConstr :: JsonError -> Constr # dataTypeOf :: JsonError -> DataType # dataCast1 :: Typeable t => (forall d. Data d => c (t d)) -> Maybe (c JsonError) # dataCast2 :: Typeable t => (forall d e. (Data d, Data e) => c (t d e)) -> Maybe (c JsonError) # gmapT :: (forall b. Data b => b -> b) -> JsonError -> JsonError # gmapQl :: (r -> r' -> r) -> r -> (forall d. Data d => d -> r') -> JsonError -> r # gmapQr :: forall r r'. (r' -> r -> r) -> r -> (forall d. Data d => d -> r') -> JsonError -> r # gmapQ :: (forall d. Data d => d -> u) -> JsonError -> [u] # gmapQi :: Int -> (forall d. Data d => d -> u) -> JsonError -> u # gmapM :: Monad m => (forall d. Data d => d -> m d) -> JsonError -> m JsonError # gmapMp :: MonadPlus m => (forall d. Data d => d -> m d) -> JsonError -> m JsonError # gmapMo :: MonadPlus m => (forall d. Data d => d -> m d) -> JsonError -> m JsonError # | |
| Show JsonError Source # | |
| Generic JsonError Source # | |
| ToJSON JsonError Source # | |
Defined in OryKratos.Types.Misc | |
| FromJSON JsonError Source # | |
| type Rep JsonError Source # | |
Defined in OryKratos.Types.Misc type Rep JsonError = D1 ('MetaData "JsonError" "OryKratos.Types.Misc" "ory-kratos-0.0.6.0-9BTeyIjpbIJHN75AXkcTl3" 'False) (C1 ('MetaCons "JsonError" 'PrefixI 'True) (S1 ('MetaSel ('Just "error") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 GenericError))) | |
data SelfServiceErrorContainer Source #
Constructors
| SelfServiceErrorContainer | |
Fields
| |
Instances
data RecoveryFlow Source #
This request is used when an identity wants to recover their account. We recommend reading the Account Recovery Documentation
Constructors
| RecoveryFlow | |
Fields
| |
Instances
data RecoveryLink Source #
Constructors
| RecoveryLink | |
Fields
| |
Instances
data SubmitSelfServiceRecoveryFlowWithLinkMethod Source #
Constructors
| SubmitSelfServiceRecoveryFlowWithLinkMethod | |
Fields
| |
Instances
data RegistrationFlow Source #
Constructors
| RegistrationFlow | |
Fields
| |
Instances
data RegistrationViaApiResponse Source #
The Response for Registration Flows via API
Constructors
| RegistrationViaApiResponse | |
Fields
| |
Instances
data SubmitSelfServiceRegistrationFlowWithPasswordMethod Source #
SubmitSelfServiceRegistrationFlowWithPasswordMethod is used to decode the registration form payload when using the password method.
Instances
data SettingsFlow Source #
This flow is used when an identity wants to update settings (e.g. profile data, passwords, ...) in a selfservice manner. We recommend reading the User Settings Documentation
Constructors
| SettingsFlow | |
Fields
| |
Instances
data SettingsViaApiResponse Source #
The Response for Settings Flows via API
Constructors
| SettingsViaApiResponse | |
Fields
| |
Instances
data SubmitSelfServiceBrowserSettingsOIDCFlowPayload Source #
Constructors
| SubmitSelfServiceBrowserSettingsOIDCFlowPayload | |
Fields
| |
Instances
data SubmitSelfServiceSettingsFlowWithPasswordMethod Source #
Constructors
| SubmitSelfServiceSettingsFlowWithPasswordMethod | |
Instances
data VerificationFlow Source #
Used to verify an out-of-band communication channel such as an email address or a phone number. For more information head over to: https://www.ory.sh/docs/kratos/selfservice/flows/verify-email-account-activation
Constructors
| VerificationFlow | |
Fields
| |
Instances
data UiContainer Source #
Container represents a HTML Form. The container can work with both HTTP Form and JSON requests
Constructors
| UiContainer | |
Instances
Nodes are represented as HTML elements or their native UI equivalents. For example, a node can be an `<img>` tag, or an `<input element>` but also `some plain text`.
Constructors
| UiNode | |
Instances
| Eq UiNode Source # | |
| Data UiNode Source # | |
Defined in OryKratos.Types.Ui Methods gfoldl :: (forall d b. Data d => c (d -> b) -> d -> c b) -> (forall g. g -> c g) -> UiNode -> c UiNode # gunfold :: (forall b r. Data b => c (b -> r) -> c r) -> (forall r. r -> c r) -> Constr -> c UiNode # toConstr :: UiNode -> Constr # dataTypeOf :: UiNode -> DataType # dataCast1 :: Typeable t => (forall d. Data d => c (t d)) -> Maybe (c UiNode) # dataCast2 :: Typeable t => (forall d e. (Data d, Data e) => c (t d e)) -> Maybe (c UiNode) # gmapT :: (forall b. Data b => b -> b) -> UiNode -> UiNode # gmapQl :: (r -> r' -> r) -> r -> (forall d. Data d => d -> r') -> UiNode -> r # gmapQr :: forall r r'. (r' -> r -> r) -> r -> (forall d. Data d => d -> r') -> UiNode -> r # gmapQ :: (forall d. Data d => d -> u) -> UiNode -> [u] # gmapQi :: Int -> (forall d. Data d => d -> u) -> UiNode -> u # gmapM :: Monad m => (forall d. Data d => d -> m d) -> UiNode -> m UiNode # gmapMp :: MonadPlus m => (forall d. Data d => d -> m d) -> UiNode -> m UiNode # gmapMo :: MonadPlus m => (forall d. Data d => d -> m d) -> UiNode -> m UiNode # | |
| Show UiNode Source # | |
| Generic UiNode Source # | |
| ToJSON UiNode Source # | |
Defined in OryKratos.Types.Ui | |
| FromJSON UiNode Source # | |
| type Rep UiNode Source # | |
Defined in OryKratos.Types.Ui type Rep UiNode = D1 ('MetaData "UiNode" "OryKratos.Types.Ui" "ory-kratos-0.0.6.0-9BTeyIjpbIJHN75AXkcTl3" 'False) (C1 ('MetaCons "UiNode" 'PrefixI 'True) ((S1 ('MetaSel ('Just "attributes") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Value) :*: S1 ('MetaSel ('Just "group") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Text)) :*: (S1 ('MetaSel ('Just "messages") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 [UiText]) :*: (S1 ('MetaSel ('Just "meta") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Meta) :*: S1 ('MetaSel ('Just "_type") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Text))))) | |
data UiNodeAnchorAttributes Source #
Constructors
| UiNodeAnchorAttributes | |
Instances
data UiNodeImageAttributes Source #
Constructors
| UiNodeImageAttributes | |
Instances
data UiNodeInputAttributes Source #
InputAttributes represents the attributes of an input node
Constructors
| UiNodeInputAttributes | |
Instances
data UiNodeTextAttributes Source #
Constructors
| UiNodeTextAttributes | |
Instances
Constructors
| UiText | |
Instances
| Eq UiText Source # | |
| Data UiText Source # | |
Defined in OryKratos.Types.Ui Methods gfoldl :: (forall d b. Data d => c (d -> b) -> d -> c b) -> (forall g. g -> c g) -> UiText -> c UiText # gunfold :: (forall b r. Data b => c (b -> r) -> c r) -> (forall r. r -> c r) -> Constr -> c UiText # toConstr :: UiText -> Constr # dataTypeOf :: UiText -> DataType # dataCast1 :: Typeable t => (forall d. Data d => c (t d)) -> Maybe (c UiText) # dataCast2 :: Typeable t => (forall d e. (Data d, Data e) => c (t d e)) -> Maybe (c UiText) # gmapT :: (forall b. Data b => b -> b) -> UiText -> UiText # gmapQl :: (r -> r' -> r) -> r -> (forall d. Data d => d -> r') -> UiText -> r # gmapQr :: forall r r'. (r' -> r -> r) -> r -> (forall d. Data d => d -> r') -> UiText -> r # gmapQ :: (forall d. Data d => d -> u) -> UiText -> [u] # gmapQi :: Int -> (forall d. Data d => d -> u) -> UiText -> u # gmapM :: Monad m => (forall d. Data d => d -> m d) -> UiText -> m UiText # gmapMp :: MonadPlus m => (forall d. Data d => d -> m d) -> UiText -> m UiText # gmapMo :: MonadPlus m => (forall d. Data d => d -> m d) -> UiText -> m UiText # | |
| Show UiText Source # | |
| Generic UiText Source # | |
| ToJSON UiText Source # | |
Defined in OryKratos.Types.Ui | |
| FromJSON UiText Source # | |
| type Rep UiText Source # | |
Defined in OryKratos.Types.Ui type Rep UiText = D1 ('MetaData "UiText" "OryKratos.Types.Ui" "ory-kratos-0.0.6.0-9BTeyIjpbIJHN75AXkcTl3" 'False) (C1 ('MetaCons "UiText" 'PrefixI 'True) ((S1 ('MetaSel ('Just "context") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Maybe Value)) :*: S1 ('MetaSel ('Just "id") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Integer)) :*: (S1 ('MetaSel ('Just "text") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Text) :*: S1 ('MetaSel ('Just "_type") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Text)))) | |
This might include a label and other information that can optionally be used to render UIs.
Instances
| Eq Meta Source # | |
| Data Meta Source # | |
Defined in OryKratos.Types.Ui Methods gfoldl :: (forall d b. Data d => c (d -> b) -> d -> c b) -> (forall g. g -> c g) -> Meta -> c Meta # gunfold :: (forall b r. Data b => c (b -> r) -> c r) -> (forall r. r -> c r) -> Constr -> c Meta # dataTypeOf :: Meta -> DataType # dataCast1 :: Typeable t => (forall d. Data d => c (t d)) -> Maybe (c Meta) # dataCast2 :: Typeable t => (forall d e. (Data d, Data e) => c (t d e)) -> Maybe (c Meta) # gmapT :: (forall b. Data b => b -> b) -> Meta -> Meta # gmapQl :: (r -> r' -> r) -> r -> (forall d. Data d => d -> r') -> Meta -> r # gmapQr :: forall r r'. (r' -> r -> r) -> r -> (forall d. Data d => d -> r') -> Meta -> r # gmapQ :: (forall d. Data d => d -> u) -> Meta -> [u] # gmapQi :: Int -> (forall d. Data d => d -> u) -> Meta -> u # gmapM :: Monad m => (forall d. Data d => d -> m d) -> Meta -> m Meta # gmapMp :: MonadPlus m => (forall d. Data d => d -> m d) -> Meta -> m Meta # gmapMo :: MonadPlus m => (forall d. Data d => d -> m d) -> Meta -> m Meta # | |
| Show Meta Source # | |
| Generic Meta Source # | |
| ToJSON Meta Source # | |
Defined in OryKratos.Types.Ui | |
| FromJSON Meta Source # | |
| type Rep Meta Source # | |
Defined in OryKratos.Types.Ui | |